@@ -103,9 +103,9 @@ add_edit_dialog_create (charpick_data *curr_data, gchar *string, gchar *title)
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (dialog))), 2);
 
-	dbox = GTK_DIALOG (dialog)->vbox;
+	dbox = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	
 	vbox = gtk_vbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (dbox), vbox, TRUE, TRUE, 0);
@@ -443,7 +443,7 @@ static void default_chars_frame_create(charpick_data *curr_data)
   GtkWidget *scrolled;
   GtkWidget *button;
 
-  dbox = GTK_DIALOG (dialog)->vbox;
+  dbox = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
   vbox = gtk_vbox_new (FALSE, 18);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
@@ -549,7 +549,7 @@ show_preferences_dialog (BonoboUIComponent *uic,
 			 gtk_widget_get_screen (curr_data->applet));
   gtk_window_set_default_size (GTK_WINDOW (curr_data->propwindow), 350, 350);
   gtk_container_set_border_width (GTK_CONTAINER (curr_data->propwindow), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (curr_data->propwindow)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (curr_data->propwindow))), 2);
   gtk_dialog_set_default_response (GTK_DIALOG (curr_data->propwindow), GTK_RESPONSE_CLOSE);
   gtk_dialog_set_has_separator (GTK_DIALOG (curr_data->propwindow), FALSE);
 
